==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceImage_shell.cpp <==
#include "QPlaceImage_shell.h"
#include <QtJambi/Cast>

void deleter_QPlaceImage(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceImage")
    QPlaceImage *_ptr = reinterpret_cast<QPlaceImage *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlaceImage_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlaceImage_shell) ); }

jmethodID QPlaceImage_shell::__shell_javaMethod(int pos) const { return QPlaceImage_shell::__shell()->javaMethod(typeid(QPlaceImage), pos); }

// emitting (writeShellConstructor)
QPlaceImage_shell::QPlaceImage_shell()
    : QPlaceImage()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceImage::QPlaceImage_shell()", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->constructed(typeid(QPlaceImage));
}

QPlaceImage_shell::QPlaceImage_shell(const QPlaceContent& other0)
    : QPlaceImage(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceImage::QPlaceImage_shell(const QPlaceContent& other0)", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->constructed(typeid(QPlaceImage));
}

// emitting (writeShellDestructor)
QPlaceImage_shell::~QPlaceImage_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlaceImage::~QPlaceImage()", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->destructed(typeid(QPlaceImage));
}

void QPlaceImage_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlaceImage_shell*>(ptr)->QPlaceImage_shell::__shell()->tryDeleteShell(typeid(QPlaceImage));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlaceImage()
void __qt_construct_QPlaceImage_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceImage()")
    Q_UNUSED(__java_arguments)
    QPlaceImage *__qt_this = new(__qtjambi_ptr) QPlaceImage_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPlaceImage(QPlaceContent)
void __qt_construct_QPlaceImage_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceImage(QPlaceContent)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceContent& __qt_other0 = qtjambi_cast<const QPlaceContent& >(__jni_env, other0);
    QPlaceImage *__qt_this = new(__qtjambi_ptr) QPlaceImage_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPlaceImage_shell
void __qt_destruct_QPlaceImage(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceImage")
    reinterpret_cast<QPlaceImage_shell*>(ptr)->~QPlaceImage_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceImage::QPlaceImage()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_initialize_1native__Lio_qt_location_QPlaceImage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceImage::QPlaceImage()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceImage_0, sizeof(QPlaceImage_shell), typeid(QPlaceImage), true, &deleter_QPlaceImage, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::QPlaceImage(QPlaceContent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_initialize_1native__Lio_qt_location_QPlaceImage_2Lio_qt_location_QPlaceContent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceImage::QPlaceImage(QPlaceContent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceImage_1, sizeof(QPlaceImage_shell), typeid(QPlaceImage), true, &deleter_QPlaceImage, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::imageId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_imageId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::imageId()const", __qt_this)
        QString __qt_return_value = __qt_this->imageId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceImage::mimeType()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_mimeType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::mimeType()const", __qt_this)
        QString __qt_return_value = __qt_this->mimeType();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceImage::setImageId(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setImageId_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring identifier0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setImageId(QString)", __qt_this)
        QString  __qt_identifier0 = qtjambi_cast<QString >(__jni_env, identifier0);
        __qt_this->setImageId(__qt_identifier0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::setMimeType(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setMimeType_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setMimeType(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString >(__jni_env, data0);
        __qt_this->setMimeType(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::setUrl(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setUrl_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setUrl(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->setUrl(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceImage(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceImage>("QPlaceImage", "io/qt/location/QPlaceImage");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceImage, {
        ConstructorInfo(&__qt_construct_QPlaceImage_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceImage_1, "Lio/qt/location/QPlaceContent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceImage);
    registerMetaType<QPlaceImage>("QPlaceImage");
    registerSizeOfShell(typeId, sizeof(QPlaceImage_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QPlaceContent, QPlaceImage>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceImage_shell.cpp <==
#include "QPlaceImage_shell.h"
#include <QtJambi/Cast>

void deleter_QPlaceImage(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceImage")
    QPlaceImage *_ptr = reinterpret_cast<QPlaceImage *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlaceImage_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlaceImage_shell) ); }

jmethodID QPlaceImage_shell::__shell_javaMethod(int pos) const { return QPlaceImage_shell::__shell()->javaMethod(typeid(QPlaceImage), pos); }

// emitting (writeShellConstructor)
QPlaceImage_shell::QPlaceImage_shell()
    : QPlaceImage()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceImage::QPlaceImage_shell()", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->constructed(typeid(QPlaceImage));
}

QPlaceImage_shell::QPlaceImage_shell(const QPlaceContent& other0)
    : QPlaceImage(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceImage::QPlaceImage_shell(const QPlaceContent& other0)", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->constructed(typeid(QPlaceImage));
}

QPlaceImage_shell::QPlaceImage_shell(const QPlaceImage& other0)
    : QPlaceImage(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceImage::QPlaceImage_shell(const QPlaceImage& other0)", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->constructed(typeid(QPlaceImage));
}

// emitting (writeShellDestructor)
QPlaceImage_shell::~QPlaceImage_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlaceImage::~QPlaceImage()", QPlaceImage_shell::__shell())
    QPlaceImage_shell::__shell()->destructed(typeid(QPlaceImage));
}

void QPlaceImage_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlaceImage_shell*>(ptr)->QPlaceImage_shell::__shell()->tryDeleteShell(typeid(QPlaceImage));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlaceImage()
void __qt_construct_QPlaceImage(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceImage()")
    Q_UNUSED(__java_arguments)
    QPlaceImage *__qt_this = new(__qtjambi_ptr) QPlaceImage_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPlaceImage::QPlaceImage()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_initialize_1native__Lio_qt_location_QPlaceImage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceImage::QPlaceImage()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceImage, sizeof(QPlaceImage_shell), typeid(QPlaceImage), true, &deleter_QPlaceImage, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceImage(QPlaceContent)
void __qt_construct_QPlaceImage_cref_QPlaceContent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceImage(QPlaceContent)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceContent& __qt_other0 = qtjambi_cast<const QPlaceContent& >(__jni_env, other0);
    QPlaceImage *__qt_this = new(__qtjambi_ptr) QPlaceImage_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceImage::QPlaceImage(QPlaceContent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_initialize_1native__Lio_qt_location_QPlaceImage_2Lio_qt_location_QPlaceContent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceImage::QPlaceImage(QPlaceContent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceImage_cref_QPlaceContent, sizeof(QPlaceImage_shell), typeid(QPlaceImage), true, &deleter_QPlaceImage, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceImage(QPlaceImage)
void __qt_construct_QPlaceImage_cref_QPlaceImage(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceImage(QPlaceImage)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceImage& __qt_other0 = qtjambi_cast<const QPlaceImage& >(__jni_env, other0);
    QPlaceImage *__qt_this = new(__qtjambi_ptr) QPlaceImage_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceImage::QPlaceImage(QPlaceImage)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_initialize_1native__Lio_qt_location_QPlaceImage_2Lio_qt_location_QPlaceImage_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceImage::QPlaceImage(QPlaceImage)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceImage_cref_QPlaceImage, sizeof(QPlaceImage_shell), typeid(QPlaceImage), true, &deleter_QPlaceImage, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPlaceImage_shell
void __qt_destruct_QPlaceImage(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceImage")
    reinterpret_cast<QPlaceImage_shell*>(ptr)->~QPlaceImage_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceImage::imageId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_imageId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::imageId()const", __qt_this)
        QString __qt_return_value = __qt_this->imageId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceImage::mimeType()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_mimeType_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::mimeType()const", __qt_this)
        QString __qt_return_value = __qt_this->mimeType();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceImage::setImageId(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setImageId_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring identifier0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setImageId(QString)", __qt_this)
        QString  __qt_identifier0 = qtjambi_cast<QString>(__jni_env, identifier0);
        __qt_this->setImageId(__qt_identifier0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::setMimeType(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setMimeType_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setMimeType(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString>(__jni_env, data0);
        __qt_this->setMimeType(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::setUrl(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_setUrl_1native_1cref_1QUrl__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID url0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::setUrl(QUrl)", __qt_this)
        const QUrl& __qt_url0 = QtJambiAPI::valueReferenceFromNativeId<QUrl>(url0);
        __qt_this->setUrl(__qt_url0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceImage::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceImage::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceImage_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceImage *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceImage>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceImage(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceImage>("QPlaceImage", "io/qt/location/QPlaceImage");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceImage, {
        ConstructorInfo(&__qt_construct_QPlaceImage, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceImage_cref_QPlaceContent, "Lio/qt/location/QPlaceContent;")
       ,ConstructorInfo(&__qt_construct_QPlaceImage_cref_QPlaceImage, "Lio/qt/location/QPlaceImage;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceImage);
    registerMetaType<QPlaceImage>("QPlaceImage");
    registerSizeOfShell(typeId, sizeof(QPlaceImage_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QPlaceContent, QPlaceImage>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
